==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/layouts/activity-panel/nl.dictionary.itop.activity-panel.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('NL NL', 'Dutch', 'Nederlands', [
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Activiteitenpaneel',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Klik om het activiteitenpaneel te openen',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Voeg item toe',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Sluit',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Laad alle vorige items',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Laad meer items',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'Door op deze knop te drukken, wordt alle invoer in elke log tegelijk opgeslagen.',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Meerdere logs opslaan',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Nog geen activiteit.',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Klik om het tabblad Notificaties te openen en meer info te zien',
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Vergroot',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Reduceer',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Activiteiten',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Concept',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Sluit alle items',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Open alle items',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Aanpassingen',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Toon / verberg aanpassingen',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Kies welke logs weergegeven worden op deze tab',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Logs',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Toon / verberg logs',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Statuswijzigingen',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Toon / verberg statuswijzigingen',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Aantal participerende personen in de zichtbare berichten',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Aantal berichten in de zichtbare logs',
]);

==> iTop-3.2.2-1-17851.zip: web/dictionaries/ui/layouts/activity-panel/nl.dictionary.itop.activity-panel.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Vergroot',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Reduceer',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Sluit',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Laad meer items',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Laad alle vorige items',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Activiteiten',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Concept',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Logs',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Toon / verberg logs',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Kies welke logs weergegeven worden op deze tab',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Statuswijzigingen',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Toon / verberg statuswijzigingen',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Aanpassingen',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Toon / verberg aanpassingen',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Open alle items',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Sluit alle items',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Aantal participerende personen in de zichtbare berichten',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Aantal berichten in de zichtbare logs',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Voeg item toe',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Meerdere logs opslaan',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'Door op deze knop te drukken, wordt alle invoer in elke log tegelijk opgeslagen.',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Klik om het tabblad Notificaties te openen en meer info te zien',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Nog geen activiteit.',
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Activiteitenpaneel',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Klik om het activiteitenpaneel te openen',
));
